@@ -3,143 +3,143 @@ context("sf_polygon")
 test_that("various objects converted to sf_polygon",{
 
   m <- matrix(1:4, ncol = 2)
-  res <- sfheaders:::rcpp_sf_polygon(m, c(0,1), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(c(1.2,3,4,5), ncol = 2)
-  res <- sfheaders:::rcpp_sf_polygon(m, c(0,1), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:4, ncol = 2)
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c(0,1), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c(0L,1L), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:4, ncol = 2)
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(c(1.2,3,4,5), ncol = 2)
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
 
   m <- matrix(1:4, ncol = 2)
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
-  res <- sfheaders:::rcpp_sf_polygon(m, c(0,1), 2, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), 2L, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1L,1L,2L,2L))
-  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), 2L, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), 2L, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
-  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), 2L, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), 2L, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
-  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), 2L, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c(0L,1L), 2L, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c(0,1), 2, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c(0L,1L), 2L, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1L,1L,2L,2L) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(c(1.2,2:8), ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), "V3", NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), "V3", NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1L,1L,2L,2L) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), "V3", "V3", close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), "V3", "V3", xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), "V3", "V3", close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), "V3", "V3", xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(c(1.2,2:8), ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), "V3", NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), "V3", NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), c("V3"), NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), c("V3"), NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), c("V3"), NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), c("V3"), NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c(0L,1L), 2L, NULL, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c(0L,1L), 2L, NULL, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1L))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c(0L,1L), NULL, 2L, close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c(0L,1L), NULL, 2L, xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, "V3", close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(df, c("V1","V2"), NULL, "V3", xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), NULL, "V3", close = FALSE, keep = TRUE, xyzm = "" )
+  res <- sfheaders:::rcpp_sf_polygon(m, c("V1","V2"), NULL, "V3", xyzm = "", keep = TRUE, close = FALSE )
   expect_true( all( attr(res, "class") == c("sf", "data.frame") ) )
 })
