@@ -8,103 +8,103 @@ test_that("various objects converted to sfc_polygon",{
     return( all(y) & all(z))
   }
 
-  v <- 1:3
-  expect_error( sfheaders:::rcpp_sfc_polygon(v, NULL, NULL, NULL, close = FALSE, ""), "sfheaders - unsupported object")
+  # v <- 1:3
+  # expect_error( sfheaders:::rcpp_sfc_polygon(v, NULL, NULL, NULL, "", close = FALSE), "geometries - unsupported object")
 
   m <- matrix(1:4, ncol = 2)
-  res <- sfheaders:::rcpp_sfc_polygon(m, NULL, NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, NULL, NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(c(1.2,3,4,5), ncol = 2)
-  res <- sfheaders:::rcpp_sfc_polygon(m, NULL, NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, NULL, NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(1:4, ncol = 2)
-  res <- sfheaders:::rcpp_sfc_polygon(m, c(0,1), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(c(1.2,3,4,5), ncol = 2)
-  res <- sfheaders:::rcpp_sfc_polygon(m, c(0,1), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(1:4, ncol = 2)
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, NULL, NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, NULL, NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(1:4, ncol = 2)
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c(0,1), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c(0L,1L), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(1:4, ncol = 2)
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(c(1.2,3,4,5), ncol = 2)
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
 
   m <- matrix(1:4, ncol = 2)
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
-  res <- sfheaders:::rcpp_sfc_polygon(m, NULL, 2, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, NULL, 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
-  res <- sfheaders:::rcpp_sfc_polygon(m, c(0,1), 2, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, NULL, 2, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, NULL, 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1L,1L,2L,2L))
-  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), 2L, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
-  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), 2L, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
-  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), 2L, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c(0L,1L), 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c(0,1), 2, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c(0L,1L), 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
@@ -112,7 +112,7 @@ test_that("various objects converted to sfc_polygon",{
   m <- cbind(m, c(1L,1L,2L,2L) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), NULL, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
@@ -120,14 +120,14 @@ test_that("various objects converted to sfc_polygon",{
   m <- cbind(m, c(1,1,2,2) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), NULL, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(c(1.2,2:8), ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
@@ -135,7 +135,7 @@ test_that("various objects converted to sfc_polygon",{
   m <- cbind(m, c(1,1,2,2) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), "V3", NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), "V3", NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
@@ -143,7 +143,7 @@ test_that("various objects converted to sfc_polygon",{
   m <- cbind(m, c(1L,1L,2L,2L) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), "V3", "V3", close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), "V3", "V3", "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
@@ -151,30 +151,28 @@ test_that("various objects converted to sfc_polygon",{
   m <- cbind(m, c(1,1,2,2) )
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), "V3", "V3", close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), "V3", "V3", "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(c(1.2,2:8), ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), "V3", NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), "V3", NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
-
-
   m <- matrix(1:8, ncol = 2)
   m <- cbind(m, c(1,1,2,2))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), c("V3"), NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), c("V3"), NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), c("V3"), NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), c("V3"), NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
@@ -182,21 +180,21 @@ test_that("various objects converted to sfc_polygon",{
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c(0L,1L), 2L, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c(0L,1L), 2L, NULL, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1L))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c(0L,1L), NULL, 2L, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c(0L,1L), NULL, 2L, "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:2, ncol = 2)
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
-  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, "V3", close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(df, c("V1","V2"), NULL, "V3", "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
@@ -204,12 +202,12 @@ test_that("various objects converted to sfc_polygon",{
   m <- cbind(m, c(1))
   df <- as.data.frame( m )
   m <- as.matrix( df )
-  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), NULL, "V3", close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon(m, c("V1","V2"), NULL, "V3", "", close = FALSE)
   expect_true( is_polygon( res ) )
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
 
   m <- matrix(1:4, ncol = 2)
-  expect_error( sfheaders:::rcpp_sfc_polygon(m, NULL, 0, NULL, close = FALSE, ""), "sfheaders - incorrect number of geometry columns")
+  expect_error( sfheaders:::rcpp_sfc_polygon(m, NULL, 0L, NULL, "", close = FALSE), "sfheaders - can't work out the dimension")
 
 })
 
@@ -257,48 +255,48 @@ test_that("sfc_polygon works", {
     , y = c(1,2,3,1,4,5,6,4)
   )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, NULL, c(0), close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, NULL, c(0L), "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, c(0), NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, c(0L), NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, c("x","y"), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, c("x","y"), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, c(2,3), NULL, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, c(2L,3L), NULL, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, 0, 1, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, NULL, 0L, 1L, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, c(2,3), 0, NULL, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, c(2L,3L), 0L, NULL, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, c(2,3), NULL, 1, close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, c(2L,3L), NULL, 1L, "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, c(2,3), c(0), c(1), close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, c(2L,3L), c(0L), c(1L), "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
   m <- as.matrix( df )
   m <- matrix( as.integer( m ), ncol = 4 )
-  res <- sfheaders:::rcpp_sfc_polygon( m, c(2,3), c(0), c(1), close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( m, c(2L,3L), c(0L), c(1L), "", close = FALSE)
   expect_true( is_polygon( res ) )
 
-  res <- sfheaders:::rcpp_sfc_polygon( df, c("x","y"),c("p_id"),c("l_id"), close = FALSE, "")
+  res <- sfheaders:::rcpp_sfc_polygon( df, c("x","y"),c("p_id"),c("l_id"), "", close = FALSE)
   expect_equal( attr( res, "class" ), c("sfc_POLYGON", "sfc") )
   expect_true( is_polygon( res ) )
 
@@ -365,7 +363,8 @@ test_that("vectorised version works",{
   m1 <- matrix(1:12, ncol = 3)
   m2 <- matrix(1:12, ncol = 3)
   lst <- list( m1, m2 )
-  res <- sfheaders:::rcpp_sfc_polygons( lst, close = FALSE, "" )
+  res <- sfheaders:::rcpp_sfc_polygons( lst, "", close = FALSE )
   expect_true( all( sapply( res, is_polygon ) ) )
 
 })
+
